@@ -232,6 +232,8 @@ class XSSTemplateParser(etree.Parser):
         config.XHTML_NS: {None: Element},
         config.META_NS: {None: MetaElement}}
 
+    fallback = Element
+    
 class DynamicHTMLParser(XSSTemplateParser):
     slots = attributes = ()
     
@@ -257,9 +259,9 @@ class DynamicHTMLParser(XSSTemplateParser):
                 new.tail = "\n"
                 tag = new
                 
-    def glob_resources(self, root, attribute, xpath, ns={}):
+    def glob_resources(self, root, attribute, xpath):
         """Resource globbing"""
-        tags = root.xpath(xpath, namespaces=ns)
+        tags = root.xpath(xpath)
         for tag in tags:
             href = tag.attrib.get(attribute)
             matches = glob.glob(os.path.join(self.path, href))
@@ -267,7 +269,8 @@ class DynamicHTMLParser(XSSTemplateParser):
                 self.expand_tag(tag, matches, attribute)
 
     def parse(self, body):
-        root, doctype = super(DynamicHTMLParser, self).parse(body)
+        tree = super(DynamicHTMLParser, self).parse(body)
+        root = tree.getroot()
 
         # set template path attribute on root element
         root.attrib[
@@ -278,19 +281,20 @@ class DynamicHTMLParser(XSSTemplateParser):
         self.attributes = []
 
         # process possible resource globbing
-        self.glob_resources(root, "href", './/xmlns:link', ns={'xmlns': config.XHTML_NS})
-        self.glob_resources(root, "src", './/xmlns:script', ns={'xmlns': config.XHTML_NS})
+        self.glob_resources(
+            root, "href", './/link')
+        self.glob_resources(
+            root, "src", './/script')
 
         # process dynamic rules
-        links = root.xpath(
-            './/xmlns:link[@rel="xss"]', namespaces={'xmlns': config.XHTML_NS})
-
+        links = root.xpath('.//link[@rel="xss"]')
         for link in links:
             try:
                 href = link.attrib['href']
             except KeyError:
                 raise AttributeError(
-                    "Attribute missing from tag: 'href' (line %d)." % link.sourceline)
+                    "Attribute missing from tag: "
+                    "'href' (line %d)." % link.sourceline)
 
             filename = os.path.join(self.path, href)
             if not os.path.exists(filename):
@@ -353,8 +357,7 @@ class DynamicHTMLParser(XSSTemplateParser):
 
         # prepare reference rebase logic
         elements = root.xpath(
-            './/xmlns:link[@href] | .//xmlns:img[@src] | .//xmlns:script[@src]',
-            namespaces={'xmlns': config.XHTML_NS})
+            './/link[@href] | .//img[@src] | .//script[@src]')
         for element in elements:
             href = element.attrib.get('href')
             if href is not None:
@@ -362,8 +365,7 @@ class DynamicHTMLParser(XSSTemplateParser):
             src = element.attrib.get('src')
             if src is not None:
                 element.attrib['{http://namespaces.repoze.org/xss}rebase'] = 'src'
-        elements = root.xpath(
-            './/xmlns:style', namespaces={'xmlns': config.XHTML_NS})
+        elements = root.xpath('.//style')
         for element in elements:
             for comment in element:
                 text = comment.text
@@ -377,4 +379,4 @@ class DynamicHTMLParser(XSSTemplateParser):
                     comment.attrib['{http://namespaces.repoze.org/xss}rebase'] = 'true'
                     comment.text = text
 
-        return root, doctype
+        return tree
